@@ -1,13 +1,13 @@
 ## no critic (ProhibitStringyEval ProhibitSubroutinePrototypes RequireLocalizedPunctuationVars)
 package Test::Expander;
 
-our $VERSION = '1.0.1';                                     ## no critic (RequireUseStrict, RequireUseWarnings)
+our $VERSION = '1.0.2';                                     ## no critic (RequireUseStrict, RequireUseWarnings)
 
 use v5.14;
 use warnings
   FATAL    => qw(all),
   NONFATAL => qw(deprecated exec internal malloc newline portable recursion);
-no  warnings  qw(experimental);
+no if ($] >= 5.018), warnings => 'experimental';
 
 use Const::Fast;
 use File::chdir;
